cms\_plots package
==================

Submodules
----------

cms\_plots.dictionary module
----------------------------

.. automodule:: seamm_dashboard_client.dictionary
   :members:
   :undoc-members:
   :show-inheritance:

cms\_plots.electronic module
----------------------------

.. automodule:: seamm_dashboard_client.electronic
   :members:
   :undoc-members:
   :show-inheritance:

cms\_plots.plotting module
--------------------------

.. automodule:: seamm_dashboard_client.plotting
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: seamm_dashboard_client
   :members:
   :undoc-members:
   :show-inheritance:
